==> _private_core_network-1.2.25.tar.gz: lib/network_resources/model/qr_data_model.dart <==
import '_model.dart';

class QrDataModel {
  int? id;
  int? qrActionType;
  int? duration;
  String? qr;
  int? expire;
  String? content;
  String? currency;
  int? price;
  String? proUniqueId;
  String? title;
  String? shopPicture;
  String? shopDisplayName;
  String? shopUniqueId;
  String? commissionsType;
  int? pourcentage;
  int? stableCosts;
  List? eventLists;
  dynamic videoCall;

  QrDeviceInfo? deviceInfo;
  HomeDetailInfo? homelidoPropertyInfo;
  ProsModel? proInfo;
  ProServiceModel? service;
  SportPrograms? arckipelSportPrograms;

  QrDataModel({
    this.id,
    this.qr,
    this.qrActionType,
    this.duration,
    this.expire,
    this.content,
    this.currency,
    this.price,
    this.proUniqueId,
    this.title,
    this.shopPicture,
    this.shopDisplayName,
    this.commissionsType,
    this.pourcentage,
    this.stableCosts,
    this.eventLists,
    this.videoCall,
    this.homelidoPropertyInfo,
    this.proInfo,
    this.service,
    this.arckipelSportPrograms,
    this.deviceInfo,
  });

  QrDataModel.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    qr = json['qr'];
    expire = json['expire'];
    qrActionType = json['qrActionType'];
    duration = json['duration'];
    content = json['content'];
    currency = json['currency'];
    price = json['price'];
    proUniqueId = json['proUniqueId'];
    title = json['title'];
    if (json['shop'] != null) {
      shopPicture = json['shop']['shopPicture'] ?? '';
      shopDisplayName = json['shop']['shopDisplayName'] ?? '';
      shopUniqueId = json['shop']['shopUniqueId'] ?? '';
    }
    commissionsType = json['commissionsType'];
    pourcentage = json['pourcentage'];
    stableCosts = json['stableCosts'];
    eventLists = json['eventLists'] ?? json['products'];
    videoCall = json['videoCall'];
    if (json['homelidoPropertyInfo'] != null)
      homelidoPropertyInfo =
          HomeDetailInfo.fromJson(json['homelidoPropertyInfo']);
    if (json['proInfo'] != null) proInfo = ProsModel.fromJson(json['proInfo']);
    if (json['service'] != null)
      service = ProServiceModel.fromJson(json['service']);
    if (json['arckipelSportPrograms'] != null)
      arckipelSportPrograms =
          SportPrograms.fromJson(json['arckipelSportPrograms']);
    if (json['deviceInfo'] != null)
      deviceInfo = QrDeviceInfo.fromJson(json['deviceInfo']);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['qr'] = this.qr;
    data['expire'] = this.expire;
    data['qrActionType'] = this.qrActionType;
    data['duration'] = this.duration;
    data['content'] = this.content;
    data['currency'] = this.currency;
    data['price'] = this.price;
    data['proUniqueId'] = this.proUniqueId;
    data['title'] = this.title;
    data['shopPicture'] = this.shopPicture;
    data['shopDisplayName'] = this.shopDisplayName;
    data['commissionsType'] = this.commissionsType;
    data['pourcentage'] = this.pourcentage;
    data['stableCosts'] = this.stableCosts;
    data['homelidoPropertyInfo'] = this.homelidoPropertyInfo?.toJson();
    data['proInfo'] = this.proInfo?.toJson();
    data['service'] = this.service?.toJson();
    data['arckipelSportPrograms'] = this.arckipelSportPrograms?.toJson();
    return data;
  }
}

class VideoCallModel {
  int? timeStart;
  int? id;
  int? realStart;
  int? realStop;
  int? proUniqueId;
  double? price;
  int? acceptBookBeforePay;
  String? shopPicture;
  String? currency;

  VideoCallModel(
      {this.timeStart,
      this.id,
      this.realStart,
      this.realStop,
      this.proUniqueId,
      this.price,
      this.acceptBookBeforePay,
      this.shopPicture,
      this.currency});

  VideoCallModel.fromJson(Map<String, dynamic> json) {
    timeStart = json['timeStart'];
    id = json['id'];
    realStart = json['realStart'];
    realStop = json['realStop'];
    proUniqueId = json['proUniqueId'];
    price = json['price'];
    acceptBookBeforePay = json['acceptBookBeforePay'];
    shopPicture = json['shopPicture'];
    currency = json['currency'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['timeStart'] = this.timeStart;
    data['id'] = this.id;
    data['realStart'] = this.realStart;
    data['realStop'] = this.realStop;
    data['proUniqueId'] = this.proUniqueId;
    data['price'] = this.price;
    data['acceptBookBeforePay'] = this.acceptBookBeforePay;
    data['shopPicture'] = this.shopPicture;
    data['currency'] = this.currency;
    return data;
  }
}

class QrDeviceInfo {
  String? id;
  String? label;
  dynamic? publicName;
  int? isRent;
  int? ownerProId;
  List<Beers>? beers;

  QrDeviceInfo(
      {this.id,
      this.label,
      this.publicName,
      this.isRent,
      this.ownerProId,
      this.beers});

  QrDeviceInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) this.id = json["id"];
    if (json["label"] is String) this.label = json["label"];
    this.publicName = json["publicName"];
    if (json["isRent"] is int) this.isRent = json["isRent"];
    if (json["ownerProId"] is int) this.ownerProId = json["ownerProId"];
    if (json["beers"] is List)
      this.beers = json["beers"] == null
          ? null
          : (json["beers"] as List).map((e) => Beers.fromJson(e)).toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["label"] = this.label;
    data["publicName"] = this.publicName;
    data["isRent"] = this.isRent;
    data["ownerProId"] = this.ownerProId;
    if (this.beers != null)
      data["beers"] = this.beers?.map((e) => e.toJson()).toList();
    return data;
  }
}

==> _private_core_network-1.2.54.tar.gz: lib/network_resources/model/qr_data_model.dart <==
import '_model.dart';

class QrDataModel {
  int? id;
  int? qrActionType;
  int? duration;
  String? qr;
  int? expire;
  String? content;
  String? currency;
  int? price;
  String? proUniqueId;
  String? title;
  String? shopPicture;
  String? shopDisplayName;
  String? shopUniqueId;
  String? commissionsType;
  int? pourcentage;
  int? stableCosts;
  List? eventLists;
  dynamic videoCall;

  QrDeviceInfo? deviceInfo;
  dynamic? homelidoPropertyInfo;
  ProsModel? proInfo;
  ProServiceModel? service;
  SportPrograms? arckipelSportPrograms;

  QrDataModel({
    this.id,
    this.qr,
    this.qrActionType,
    this.duration,
    this.expire,
    this.content,
    this.currency,
    this.price,
    this.proUniqueId,
    this.title,
    this.shopPicture,
    this.shopDisplayName,
    this.commissionsType,
    this.pourcentage,
    this.stableCosts,
    this.eventLists,
    this.videoCall,
    this.homelidoPropertyInfo,
    this.proInfo,
    this.service,
    this.arckipelSportPrograms,
    this.deviceInfo,
  });

  QrDataModel.fromJson(Map<String, dynamic> json, {homelidoMeetingConvertor}) {
    id = json['id'];
    qr = json['qr'];
    expire = json['expire'];
    qrActionType = json['qrActionType'];
    duration = json['duration'];
    content = json['content'];
    currency = json['currency'];
    price = json['price'];
    proUniqueId = json['proUniqueId'];
    title = json['title'];
    if (json['shop'] != null) {
      shopPicture = json['shop']['shopPicture'] ?? '';
      shopDisplayName = json['shop']['shopDisplayName'] ?? '';
      shopUniqueId = json['shop']['shopUniqueId'] ?? '';
    }
    commissionsType = json['commissionsType'];
    pourcentage = json['pourcentage'];
    stableCosts = json['stableCosts'];
    eventLists = json['eventLists'] ?? json['products'];
    videoCall = json['videoCall'];
    if (json['homelidoPropertyInfo'] != null &&
        homelidoMeetingConvertor != null) {
      homelidoPropertyInfo =
          homelidoMeetingConvertor(json['homelidoPropertyInfo']);
    }

    if (json['proInfo'] != null) proInfo = ProsModel.fromJson(json['proInfo']);
    if (json['service'] != null)
      service = ProServiceModel.fromJson(json['service']);
    if (json['arckipelSportPrograms'] != null)
      arckipelSportPrograms =
          SportPrograms.fromJson(json['arckipelSportPrograms']);
    if (json['deviceInfo'] != null)
      deviceInfo = QrDeviceInfo.fromJson(json['deviceInfo']);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['qr'] = this.qr;
    data['expire'] = this.expire;
    data['qrActionType'] = this.qrActionType;
    data['duration'] = this.duration;
    data['content'] = this.content;
    data['currency'] = this.currency;
    data['price'] = this.price;
    data['proUniqueId'] = this.proUniqueId;
    data['title'] = this.title;
    data['shopPicture'] = this.shopPicture;
    data['shopDisplayName'] = this.shopDisplayName;
    data['commissionsType'] = this.commissionsType;
    data['pourcentage'] = this.pourcentage;
    data['stableCosts'] = this.stableCosts;
    data['homelidoPropertyInfo'] = this.homelidoPropertyInfo?.toJson();
    data['proInfo'] = this.proInfo?.toJson();
    data['service'] = this.service?.toJson();
    data['arckipelSportPrograms'] = this.arckipelSportPrograms?.toJson();
    return data;
  }
}

class VideoCallModel {
  int? timeStart;
  int? id;
  int? realStart;
  int? realStop;
  int? proUniqueId;
  double? price;
  int? acceptBookBeforePay;
  String? shopPicture;
  String? currency;

  VideoCallModel(
      {this.timeStart,
      this.id,
      this.realStart,
      this.realStop,
      this.proUniqueId,
      this.price,
      this.acceptBookBeforePay,
      this.shopPicture,
      this.currency});

  VideoCallModel.fromJson(Map<String, dynamic> json) {
    timeStart = json['timeStart'];
    id = json['id'];
    realStart = json['realStart'];
    realStop = json['realStop'];
    proUniqueId = json['proUniqueId'];
    price = json['price'];
    acceptBookBeforePay = json['acceptBookBeforePay'];
    shopPicture = json['shopPicture'];
    currency = json['currency'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['timeStart'] = this.timeStart;
    data['id'] = this.id;
    data['realStart'] = this.realStart;
    data['realStop'] = this.realStop;
    data['proUniqueId'] = this.proUniqueId;
    data['price'] = this.price;
    data['acceptBookBeforePay'] = this.acceptBookBeforePay;
    data['shopPicture'] = this.shopPicture;
    data['currency'] = this.currency;
    return data;
  }
}

class QrDeviceInfo {
  String? id;
  String? label;
  dynamic? publicName;
  int? isRent;
  int? ownerProId;
  List<Beers>? beers;

  QrDeviceInfo(
      {this.id,
      this.label,
      this.publicName,
      this.isRent,
      this.ownerProId,
      this.beers});

  QrDeviceInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) this.id = json["id"];
    if (json["label"] is String) this.label = json["label"];
    this.publicName = json["publicName"];
    if (json["isRent"] is int) this.isRent = json["isRent"];
    if (json["ownerProId"] is int) this.ownerProId = json["ownerProId"];
    if (json["beers"] is List)
      this.beers = json["beers"] == null
          ? null
          : (json["beers"] as List).map((e) => Beers.fromJson(e)).toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["label"] = this.label;
    data["publicName"] = this.publicName;
    data["isRent"] = this.isRent;
    data["ownerProId"] = this.ownerProId;
    if (this.beers != null)
      data["beers"] = this.beers?.map((e) => e.toJson()).toList();
    return data;
  }
}
